@@ -2,6 +2,7 @@ from collections import OrderedDict
 from copy import deepcopy
 from dataclasses import dataclass
 from enum import Enum
+from importlib.metadata import version as get_version
 import json
 import pathlib
 import string
@@ -18,9 +19,10 @@ from aporia.as_code.resources.segment import Segment
 from aporia.as_code.resources.version import Version
 from aporia.sdk.aporia_api import Aporia
 from aporia.sdk.aporia_api import BaseAporiaResource as SDKBaseAporiaResource
-from aporia.sdk.client import Client
+from aporia.sdk.client import Client, EntityNotFoundException
 from aporia.sdk.custom_metrics import CustomMetric as SDKCustomMetric
 from aporia.sdk.datasets import Dataset as SDKDataset
+from aporia.sdk.metrics import MetricType
 from aporia.sdk.models import Model as SDKModel
 from aporia.sdk.models import ModelColor
 from aporia.sdk.monitors import (
@@ -28,13 +30,14 @@ from aporia.sdk.monitors import (
     infer_detection_method,
     LogicEvaluationType,
     MessagingIntegrationType,
-    MetricType,
 )
 from aporia.sdk.monitors import Monitor as SDKMonitor
 from aporia.sdk.monitors import MonitorType, parse_monitor_configuration, PreConditionType
 from aporia.sdk.segments import Segment as SDKSegment
 from aporia.sdk.versions import Version as SDKVersion
 
+sdk_version = get_version("aporia")
+
 
 class StackAction(Enum):
     CREATE = "create"
@@ -178,7 +181,7 @@ class Stack:
                         f"Resource deletion missed for {sub_resource_unique_id}. Stack potentially corrupted."
                     )
 
-    def _create(self) -> Tuple[Dict, Optional[Exception]]:
+    def _create(self, debug: bool = False) -> Tuple[Dict, Optional[Exception]]:
         output = self._output or {}
         error = None
         try:
@@ -193,6 +196,8 @@ class Stack:
                     resource_entry.resource.deferred_load(self._client, resource_entry.resource)
 
                 if resource_entry.status is ResourceStatus.MISSING:
+                    if debug:
+                        print(f"Attempting to create: {unique_id}")
                     _, resource_data = resource_entry.resource.create(client=self._client)
                 elif resource_entry.status is ResourceStatus.DEPRECATED:
                     resource_data = resource_entry.resource.update(
@@ -209,6 +214,8 @@ class Stack:
             non_deleteable_resources = []
             for unique_id, resource_class in list(self._delete_resources.items())[::-1]:
                 resource_data = self._output[unique_id]
+                if debug:
+                    print(f"Attempting to delete: {unique_id}")
                 try:
                     resource_class.delete(client=self._client, id=resource_data["id"])
                 except NonDeletableResourceException:
@@ -503,8 +510,15 @@ class Stack:
                         if len(messaging) > 0:
                             code += f"\tmessaging={messaging},\n"
                         added_alert = True
-                        if action.maxAlertsPerDay is not None:
-                            code += f"\tmax_alerts_per_day={action.maxAlertsPerDay},\n"
+                        if action.alertGroupByEntity is not None:
+                            code += f"\talertGroupByEntity={action.alertGroupByEntity},\n"
+                        if action.alertGroupByTime is not None:
+                            code += f"\talertGroupByTime={action.alertGroupByTime},\n"
+                        if action.alertGroupTimeQuantity is not None:
+                            code += f"\talertGroupTimeQuantity={action.alertGroupTimeQuantity},\n"
+                        if action.alertGroupTimeUnit is not None:
+                            code += f"\talertGroupTimeUnit={action.alertGroupTimeUnit},\n"
+                        
 
             # Precondition Configuration
             added_min = False
@@ -764,12 +778,31 @@ def add_model(stack: aporia.Stack):
         with open(output_path / "main.py", "w") as python_file:
             python_file.write("\n".join(code))
 
+    def _refresh_config(self):
+        new_config = {}
+        for unique_id, resource in self._output.items():
+            resource_type = resource["_resource_type"]
+            resource_name = f"{resource_type}/{unique_id.split('/')[-1]}"
+            print('Refreshing resource: {:80.80s}'.format(resource_name), end='\r')
+            try:
+                new_config[unique_id] = RESOURCE_TYPE_TO_RESOURCE_CLASS[resource_type].read(
+                    client=self._client, id=resource["id"]
+                )
+                new_config[unique_id]["_resource_type"] = resource_type
+            except EntityNotFoundException:
+                print(f"{resource_type} - {unique_id} not found, removing from config")
+            except Exception as e:
+                print(f"issue refreshing data for: {resource_type} - {unique_id}")
+                raise e
+        print("Refresh complete" + (100 * ' '))
+        self._output = new_config
+
     def apply(
         self,
         action: StackAction = StackAction.CREATE,
         skip_preview: bool = False,
         yes: bool = False,
-        rollback=True,
+        rollback=True,  # BUG: Deletes all resources always
         yes_rollback=False,
         config_path: Optional[str] = None,
         debug: Optional[bool] = False,
@@ -780,7 +813,17 @@ def add_model(stack: aporia.Stack):
         if config_path is not None:
             try:
                 with open(config_path, "r") as f:
-                    self._output = json.loads(f.read())
+                    stack_data = json.loads(f.read())
+                    if "version" in stack_data and type(stack_data["version"]) is str:
+                        stack_version = stack_data["version"]
+                        self._output = stack_data["resources"]
+                    else:
+                        stack_version = '0'
+                        self._output = stack_data
+                    if sdk_version < stack_version:
+                        raise Exception(
+                            "SDK version is older than config version, please update aporia SDK (pip install --upgrade aporia)"
+                        )
                     self._diff()
             except FileNotFoundError:
                 # It's OK if the file wasn't found. It's probably the first run
@@ -793,7 +836,7 @@ def add_model(stack: aporia.Stack):
                 if input("Do create? [Y/N] ").lower().strip() not in ["y"]:
                     print("Cancelling...")
                     return
-            self._output, error = self._create()
+            self._output, error = self._create(debug=debug)
 
             if error is not None:
                 if debug:
@@ -807,7 +850,9 @@ def add_model(stack: aporia.Stack):
                             error = self._destroy()
                             if error is not None:
                                 if debug:
-                                    traceback.print_exception(error, tb=error.__traceback__, value=error)
+                                    traceback.print_exception(
+                                        error, tb=error.__traceback__, value=error
+                                    )
                                 else:
                                     print(error)
         elif action is StackAction.PREVIEW:
@@ -830,12 +875,14 @@ def add_model(stack: aporia.Stack):
         elif action is StackAction.DIFF:
             self._get_diff_config(output_format=diff_format)
             return
+        elif action is StackAction.REFRESH:
+            self._refresh_config()
         else:
             raise ValueError("Unknown action")
 
         if config_path is not None:
             with open(config_path, "w") as f:
-                f.write(json.dumps(self._output))
+                f.write(json.dumps({"version": sdk_version, "resources": self._output}))
 
     def get_resource_id(self, unique_id: str) -> str:
         return self._output[unique_id]["id"]
