@@ -18,6 +18,8 @@ class DataSourceType(Enum):
     SNOWFLAKE_NATIVE = "snowflake_native"
     GOOGLE_CLOUD_STORAGE = "google_cloud_storage"
     HIVE = "hive"
+    MSSQL = "mssql"
+    APORIA_DEMO_DATA = "aporia-demo"
 
 
 class DataSource(BaseAporiaResource):
@@ -58,13 +60,11 @@ class DataSource(BaseAporiaResource):
                 print(f"Data source {name} already exists! Using it. Check configuration")
                 return data_source
 
-        connection_data['type'] = data_source_type.value
+        connection_data["type"] = data_source_type.value
         response = client.send_request(
             "/data-sources",
             "POST",
-            {"name": name, "type": data_source_type.value, "connection": connection_data},
-            # TODO: Hack until data-sources are creatable using stable API
-            url_search_replace=("/api/v1/", "/v1/crud-service/"),
+            {"name": name, "connection": connection_data},
         )
 
         client.assert_response(response)
@@ -92,8 +92,6 @@ class DataSource(BaseAporiaResource):
         response = self.client.send_request(
             f"/data-sources/{self.id}",
             "DELETE",
-            # TODO: Hack until data-sources are deleteable using stable API
-            url_search_replace=("/api/v1/", "/v1/crud-service/"),
         )
         self.client.assert_response(response)
 
@@ -102,7 +100,5 @@ class DataSource(BaseAporiaResource):
         response = client.send_request(
             f"/data-sources/{id}",
             "DELETE",
-            # TODO: Hack until data-sources are deleteable using stable API
-            url_search_replace=("/api/v1/", "/v1/crud-service/"),
         )
         client.assert_response(response)
