@@ -6,24 +6,14 @@ from pydantic import BaseModel
 from aporia.sdk.base import BaseAporiaResource
 from aporia.sdk.client import Client
 from aporia.sdk.data_sources import DataSource
+from aporia.sdk.fields import FieldType
 
 
-class DatasetType(Enum):
+class DatasetType(str, Enum):
     SERVING = "serving"
     TRAINING = "training"
 
 
-class FieldType(Enum):
-    BOOLEAN = "boolean"
-    NUMERIC = "numeric"
-    DATETIME = "datetime"
-    CATEGORICAL = "categorical"
-    TEXT = "text"
-    ARRAY = "array"
-    EMBEDDING = "embedding"
-    IMAGE_URL = "image_url"
-
-
 class FieldSchema(BaseModel):
     name: str
     type: FieldType
@@ -207,8 +197,10 @@ class Dataset(BaseAporiaResource):
         self.raw_data["data_source_id"] = data["data_source_id"]
 
     def delete(self):
-        raise NotImplementedError()
+        response = self.client.send_request(f"/datasets/{self.id}", "DELETE")
+        self.client.assert_response(response)
 
     @staticmethod
     def delete_by_id(client: Client, id: str):
-        raise NotImplementedError()
+        response = client.send_request(f"/datasets/{id}", "DELETE")
+        client.assert_response(response)
