@@ -1,4 +1,5 @@
 import datetime
+from enum import Enum
 from typing import Any, Dict, List, Optional, Union
 
 from pydantic import BaseModel
@@ -7,6 +8,77 @@ from aporia.sdk.client import Client
 from aporia.sdk.datasets import DatasetType
 
 
+class MetricType(str, Enum):
+    COUNT = "count"
+    MEAN = "mean"
+    MEAN_LENGTH = "mean_length"
+    MIN = "min"
+    MEDIAN = "median"
+    MIN_LENGTH = "min_length"
+    MAX = "max"
+    MAX_LENGTH = "max_length"
+    SUM = "sum"
+    MISSING_COUNT = "missing_count"
+    MISSING_RATIO = "missing_ratio"
+    TP_COUNT = "tp_count"
+    TN_COUNT = "tn_count"
+    FP_COUNT = "fp_count"
+    FN_COUNT = "fn_count"
+    ACCURACY = "accuracy"
+    RECALL = "recall"
+    PRECISION = "precision"
+    F1 = "f1"
+    MSE = "mse"
+    RMSE = "rmse"
+    MAE = "mae"
+    ACCURACY_AT_K = "accuracy_at_k"
+    PRECISION_AT_K = "precision_at_k"
+    RECALL_AT_K = "recall_at_k"
+    MAP_AT_K = "map_at_k"
+    MRR_AT_K = "mrr_at_k"
+    NDCG_AT_K = "ndcg_at_k"
+    JS_DISTANCE = "js_distance"
+    KS_DISTANCE = "ks_distance"
+    HELLINGER_DISTANCE = "hellinger_distance"
+    EUCLIDEAN_DISTANCE = "euclidean_distance"
+    PSI = "psi"
+    ACCURACY_PER_CLASS = "accuracy_per_class"
+    PRECISION_PER_CLASS = "precision_per_class"
+    RECALL_PER_CLASS = "recall_per_class"
+    F1_PER_CLASS = "f1_per_class"
+    TP_COUNT_PER_CLASS = "tp_count_per_class"
+    TN_COUNT_PER_CLASS = "tn_count_per_class"
+    FP_COUNT_PER_CLASS = "fp_count_per_class"
+    FN_COUNT_PER_CLASS = "fn_count_per_class"
+    # Non-aggregable metrics
+    AUUC = "auuc"
+    # None-Dashboard metrics
+    LAST_VERSION_CREATION = "last_version_creation"
+    HISTOGRAM = "histogram"
+    MIN_MAX = "min_max"
+    UNIQUE_VALUES = "unique_values"
+    MISSING = "missing"
+    # Custom metrics
+    CUSTOM_METRIC = "custom_metric"
+    CODE = "code"
+
+
+def is_model_metric(metric: MetricType) -> bool:
+    return metric is MetricType.COUNT
+
+
+def is_custom_metric(metric: MetricType) -> bool:
+    return metric is MetricType.CUSTOM_METRIC
+
+
+def is_code_based_metric(metric: MetricType) -> bool:
+    return metric is MetricType.CODE
+
+
+def is_aggregable_metric(metric: MetricType) -> bool:
+    return not (metric is MetricType.CODE or metric is MetricType.AUUC)
+
+
 class TimeRange(BaseModel):
     start: datetime.datetime
     end: datetime.datetime  # "2023-05-12T00:00:00.000000+00:00"
