@@ -4,7 +4,7 @@ from typing import Dict, List, Optional, Union, Tuple
 from aporia.sdk.base import BaseAporiaResource
 from aporia.sdk.client import Client
 from aporia.sdk.custom_metrics import CustomMetric
-from aporia.sdk.dashboards import Widget
+from aporia.sdk.fields import Field
 from aporia.sdk.monitors import Monitor, MonitorConfiguration, MonitorType
 from aporia.sdk.segments import Segment
 from aporia.sdk.versions import Version
@@ -192,9 +192,6 @@ class Model(BaseAporiaResource):
         )
         return monitor
 
-    def create_dashboard(self, widgets: List[Widget]):
-        pass
-
     def get_versions(self) -> List[Version]:
         versions = Version.get_all(client=self.client, model_id=self.id)
         return versions
@@ -211,6 +208,16 @@ class Model(BaseAporiaResource):
         monitors = Monitor.get_all(client=self.client, model_id=self.id)
         return monitors
 
+    def get_fields(self) -> List[Field]:
+        fields = Field.get_model_fields(client=self.client, model_id=self.id)
+        return fields
+
+    def get_field_by_name(self, name: str) -> Field:
+        for field in self.get_fields():
+            if field.name == name:
+                return field
+        raise ValueError(f"Field '{name}' not found")
+
     def _get_calculation_status(self) -> str:
         response = self.client.send_request(
             "/default_metrics/get_status",
