@@ -1,11 +1,12 @@
 from enum import Enum
 from typing import Any, Callable, Dict, List, Optional, Union
 
-from pydantic import BaseModel, root_validator, validator, ValidationError
+from pydantic import BaseModel, root_validator, validator
 
 from aporia.sdk.base import BaseAporiaResource
 from aporia.sdk.client import Client
 from aporia.sdk.messaging import MessagingIntegrationType
+from aporia.sdk.metrics import MetricType
 
 SEGMENT_ID_ALL_DATA = "ALLDATA"
 
@@ -175,56 +176,7 @@ class BaselineConfiguration(BaseModel):
         return result
 
 
-class MetricType(Enum):
-    COUNT = "count"
-    MISSING_RATIO = "missing_ratio"
-    LAST_VERSION_CREATION = "last_version_creation"
-    HISTOGRAM = "histogram"
-    MIN_MAX = "min_max"
-    UNIQUE_VALUES = "unique_values"
-    CUSTOM_METRIC = "custom_metric"
-    MEAN = "mean"
-    MEAN_LENGTH = "mean_length"
-    MIN = "min"
-    MIN_LENGTH = "min_length"
-    MAX = "max"
-    MAX_LENGTH = "max_length"
-    SUM = "sum"
-    MISSING_COUNT = "missing_count"
-    MISSING = "missing"
-    TP_COUNT = "tp_count"
-    TN_COUNT = "tn_count"
-    FP_COUNT = "fp_count"
-    FN_COUNT = "fn_count"
-    ACCURACY = "accuracy"
-    RECALL = "recall"
-    PRECISION = "precision"
-    F1 = "f1"
-    MSE = "mse"
-    RMSE = "rmse"
-    MAE = "mae"
-    ACCURACY_AT_K = "accuracy_at_k"
-    PRECISION_AT_K = "precision_at_k"
-    RECALL_AT_K = "recall_at_k"
-    MAP_AT_K = "map_at_k"
-    MRR_AT_K = "mrr_at_k"
-    NDCG_AT_K = "ndcg_at_k"
-    JS_DISTANCE = "js_distance"
-    KS_DISTANCE = "ks_distance"
-    HELLINGER_DISTANCE = "hellinger_distance"
-    EUCLIDEAN_DISTANCE = "euclidean_distance"
-    PSI = "psi"
-    ACCURACY_PER_CLASS = "accuracy_per_class"
-    PRECISION_PER_CLASS = "precision_per_class"
-    RECALL_PER_CLASS = "recall_per_class"
-    F1_PER_CLASS = "f1_per_class"
-    TP_COUNT_PER_CLASS = "tp_count_per_class"
-    TN_COUNT_PER_CLASS = "tn_count_per_class"
-    FP_COUNT_PER_CLASS = "fp_count_per_class"
-    FN_COUNT_PER_CLASS = "fn_count_per_class"
-
-
-class AverageMethod(Enum):
+class AverageMethod(str, Enum):
     MICRO = "micro"
     MACRO = "macro"
     WEIGHTED = "weighted"
@@ -514,8 +466,11 @@ class ActionConfiguration(BaseModel):
     description: str
     notification: List  # TODO: Look deeper into that
     action_schema: str = "v1"  # TODO: Realize what to do with it
-    maxAlertsPerDay: Optional[int] = None
     visualization: Optional[VisualizationType] = None
+    alertGroupByTime: Optional[bool] = None
+    alertGroupByEntity: Optional[bool] = None
+    alertGroupTimeUnit: Optional[PeriodType] = None
+    alertGroupTimeQuantity: Optional[int] = None
 
     def to_dict(self):
         result = {
@@ -525,10 +480,16 @@ class ActionConfiguration(BaseModel):
             "description": self.description,
             "notification": self.notification,
             "schema": self.action_schema,
+            "alertGroupByTime": self.alertGroupByTime if self.alertGroupByTime else False,
+            "alertGroupByEntity": self.alertGroupByEntity if self.alertGroupByEntity else True,
+            "alertGroupTimeUnit": str(self.alertGroupTimeUnit.value)
+            if self.alertGroupTimeUnit
+            else str(PeriodType.DAYS.value),
+            "alertGroupTimeQuantity": self.alertGroupTimeQuantity
+            if self.alertGroupTimeQuantity
+            else 1,
         }
 
-        if self.maxAlertsPerDay is not None:
-            result["maxAlertsPerDay"] = self.maxAlertsPerDay
         if self.visualization is not None:
             result["visualization"] = self.visualization.value
 
@@ -738,12 +699,10 @@ class Monitor(BaseAporiaResource):
             args["creator"] = creator
         if is_active is not None:
             args["is_active"] = is_active
-        # response = self.client.send_request(f"/monitors/{self.id}", "PUT", args)
         response = self.client.send_request(
             f"/monitors/{self.id}",
             "PUT",
             args,
-            url_search_replace=("/api/v1/", "/v1/crud-service/"),
         )
         self.client.assert_response(response)
         self.__update_members(response.json())
@@ -850,6 +809,13 @@ def _MonitorParamBuilder(
 
     return _MonitorParams
 
+def build_drift_metric(**kw) -> MetricConfiguration:
+    type = MetricType.HISTOGRAM
+    if kw["metric"] is not None:
+        type = MetricType(kw["metric"])
+    elif kw["is_embedding"]:
+        type = MetricType.EUCLIDEAN_DISTANCE
+    return MetricConfiguration(type=type)
 
 _MONITOR_PARAMETERS = {
     MonitorType.MODEL_ACTIVITY: {
@@ -904,9 +870,7 @@ _MONITOR_PARAMETERS = {
             visualization_builder=lambda **kw: VisualizationType.EMBEDDING_DRIFT_CHART
             if kw["is_embedding"]
             else VisualizationType.DISTRIBUTION_COMPARE_CHART,
-            metric_builder=lambda **kw: MetricConfiguration(
-                type=MetricType.EUCLIDEAN_DISTANCE if kw["is_embedding"] else MetricType.HISTOGRAM
-            ),
+            metric_builder=build_drift_metric,
             logic_evaluation_builder=lambda **kw: LogicEvaluationConfiguration(
                 name=LogicEvaluationType.RANGE, min=0, max=kw["max"]
             )
@@ -922,9 +886,7 @@ _MONITOR_PARAMETERS = {
             visualization_builder=lambda **kw: VisualizationType.EMBEDDING_DRIFT_CHART
             if kw["is_embedding"]
             else VisualizationType.DISTRIBUTION_COMPARE_CHART,
-            metric_builder=lambda **kw: MetricConfiguration(
-                type=MetricType.EUCLIDEAN_DISTANCE if kw["is_embedding"] else MetricType.HISTOGRAM
-            ),
+            metric_builder=build_drift_metric,
             logic_evaluation_builder=lambda **kw: LogicEvaluationConfiguration(
                 name=LogicEvaluationType.RANGE, min=0, max=kw["max"]
             )
@@ -940,9 +902,7 @@ _MONITOR_PARAMETERS = {
             visualization_builder=lambda **kw: VisualizationType.EMBEDDING_DRIFT_CHART
             if kw["is_embedding"]
             else VisualizationType.DISTRIBUTION_COMPARE_CHART,
-            metric_builder=lambda **kw: MetricConfiguration(
-                type=MetricType.EUCLIDEAN_DISTANCE if kw["is_embedding"] else MetricType.HISTOGRAM
-            ),
+            metric_builder=build_drift_metric,
             logic_evaluation_builder=lambda **kw: LogicEvaluationConfiguration(
                 name=LogicEvaluationType.RANGE, min=0, max=kw["max"]
             )
@@ -960,9 +920,7 @@ _MONITOR_PARAMETERS = {
             visualization_builder=lambda **kw: VisualizationType.EMBEDDING_DRIFT_CHART
             if kw["is_embedding"]
             else VisualizationType.DISTRIBUTION_COMPARE_CHART,
-            metric_builder=lambda **kw: MetricConfiguration(
-                type=MetricType.EUCLIDEAN_DISTANCE if kw["is_embedding"] else MetricType.HISTOGRAM
-            ),
+            metric_builder=build_drift_metric,
             logic_evaluation_builder=lambda **kw: LogicEvaluationConfiguration(
                 name=LogicEvaluationType.RANGE, min=0, max=kw["max"]
             )
@@ -978,9 +936,7 @@ _MONITOR_PARAMETERS = {
             visualization_builder=lambda **kw: VisualizationType.EMBEDDING_DRIFT_CHART
             if kw["is_embedding"]
             else VisualizationType.DISTRIBUTION_COMPARE_CHART,
-            metric_builder=lambda **kw: MetricConfiguration(
-                type=MetricType.EUCLIDEAN_DISTANCE if kw["is_embedding"] else MetricType.HISTOGRAM
-            ),
+            metric_builder=build_drift_metric,
             logic_evaluation_builder=lambda **kw: LogicEvaluationConfiguration(
                 name=LogicEvaluationType.RANGE, min=0, max=kw["max"]
             )
@@ -996,9 +952,7 @@ _MONITOR_PARAMETERS = {
             visualization_builder=lambda **kw: VisualizationType.EMBEDDING_DRIFT_CHART
             if kw["is_embedding"]
             else VisualizationType.DISTRIBUTION_COMPARE_CHART,
-            metric_builder=lambda **kw: MetricConfiguration(
-                type=MetricType.EUCLIDEAN_DISTANCE if kw["is_embedding"] else MetricType.HISTOGRAM
-            ),
+            metric_builder=build_drift_metric,
             logic_evaluation_builder=lambda **kw: LogicEvaluationConfiguration(
                 name=LogicEvaluationType.RANGE, min=0, max=kw["max"]
             )
@@ -1526,12 +1480,15 @@ def create_monitor_configuration(
     segment_identification: Optional[SegmentIdentification] = None,
     messaging: Optional[Dict[MessagingIntegrationType, List[str]]] = None,
     emails: Optional[List[str]] = None,
-    max_alerts_per_day: Optional[int] = None,
     k: Optional[int] = None,
     prediction_class: Optional[Any] = None,
     prediction_threshold: Optional[float] = None,
     average_method: Optional[AverageMethod] = None,
     custom_metric_id: Optional[str] = None,
+    group_by_time: Optional[bool] = None,
+    group_by_entity: Optional[bool] = None,
+    alert_group_time_unit: Optional[PeriodType] = None,
+    alert_group_time_quantity: Optional[int] = None,
 ) -> MonitorConfiguration:
     """Creates a monitor configuration by the given parameters."""
     if segment_identification is None:
@@ -1545,7 +1502,9 @@ def create_monitor_configuration(
 
     if min_baseline_prediction_count is not None:
         if baseline is None:
-            raise ValueError("Can't specify min_baseline_prediction_count for monitors with no baseline")
+            raise ValueError(
+                "Can't specify min_baseline_prediction_count for monitors with no baseline"
+            )
         preconditions.append(
             PreConditionConfiguration(
                 name=PreConditionType.MIN_BASELINE_DATA_POINTS, value=min_baseline_prediction_count
@@ -1617,8 +1576,11 @@ def create_monitor_configuration(
                 alertType=monitor_params.alert_type,
                 description=monitor_params.description,
                 notification=notifications,
-                maxAlertsPerDay=max_alerts_per_day,
                 visualization=monitor_params.visualization,
+                alertGroupByTime=group_by_time,
+                alertGroupByEntity=group_by_entity,
+                alertGroupTimeUnit=alert_group_time_unit,
+                alertGroupTimeQuantity=alert_group_time_quantity,
             )
         ],
     )
